==> apache-netbeans-java-22.9.9-sources.zip: enterprise/cloud.oracle/src/org/netbeans/modules/cloud/oracle/database/DatabaseItem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.cloud.oracle.database;

import org.netbeans.modules.cloud.oracle.items.OCID;
import org.netbeans.modules.cloud.oracle.items.OCIItem;

/**
 *
 * @author Jan Horvath
 */
public class DatabaseItem extends OCIItem {
    private final String serviceUrl;
    private final String connectionName;

    public DatabaseItem(OCID id, String compartmentId, String name, String serviceUrl, String connectionName) {
        super(id, compartmentId, name);
        this.serviceUrl = serviceUrl;
        this.connectionName = connectionName;
    }

    public DatabaseItem() {
        super();
        serviceUrl = null;
        connectionName = null;
    }
    
    public String getServiceUrl() {
        return serviceUrl;
    }

    public String getConnectionName() {
        return connectionName;
    }

    @Override
    public int maxInProject() {
        return Integer.MAX_VALUE;
    }
    
}

==> apache-netbeans-java-23.9.9-sources.zip: enterprise/cloud.oracle/src/org/netbeans/modules/cloud/oracle/database/DatabaseItem.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.cloud.oracle.database;

import org.netbeans.modules.cloud.oracle.items.OCID;
import org.netbeans.modules.cloud.oracle.items.OCIItem;

/**
 *
 * @author Jan Horvath
 */
public class DatabaseItem extends OCIItem {
    private final String serviceUrl;
    private final String connectionName;

    public DatabaseItem(OCID id, String compartmentId, String name, String serviceUrl, String connectionName, String tenancyId, String regionCode) {
        super(id, compartmentId, name, tenancyId, regionCode);
        this.serviceUrl = serviceUrl;
        this.connectionName = connectionName;
    }

    public DatabaseItem() {
        super();
        serviceUrl = null;
        connectionName = null;
    }
    
    public String getServiceUrl() {
        return serviceUrl;
    }

    public String getConnectionName() {
        return connectionName;
    }

    @Override
    public int maxInProject() {
        return Integer.MAX_VALUE;
    }
    
}
